C
C *** INPUT OF FAULT RARAMETERS FROM FILE ***
C
      SUBROUTINE H2DIN(XF,ZF,W,DA,D,VRR,RT)
C
C** DATA **
C XF    : FAULT LOCATION ON X-AXIS 
C ZF    : FAULT LOCATION ON Z-AXIS 
C W     : WIDTH OF FAULT
C DA    : DIP ANGLE OF FAULT (DEGREE--->RADIAN IN THIS SUBROUTINE)
C D     : DISPLACEMENT DIFFELENCE OF FAULT
C VRR   : RUPTURE VELOCITY OF FAULT
C RT    : RISE TIME
C
      IMPLICIT REAL*8(A-H,O-Z)
      CHARACTER FNAME*30
C
C *** INPUT OF FAULT PARAMETERS FROM FILE DATA ***
C
      WRITE(*,*)
      WRITE(*,1000)
   10 WRITE(*,1010)
      READ(*,'(A)')FNAME
      IF(FNAME(1:1).EQ.' ')GOTO 10
 1000 FORMAT( ' From SUBROUTINE H2DIN :')
 1010 FORMAT(/' Enter File Name of 2-D SH Haskell''s Fault Model :',\)

      OPEN (7,FILE=FNAME)
        READ(7,1200)XF,ZF
        READ(7,1200)W,DA,D
        READ(7,1200)VRR,RT
      CLOSE(7)
 1200 FORMAT(3F10.0)
C
C *** DEGREE => RADIAN ***
C
      DA1=DA
      DA=DA*3.141592654D0/180.D0
C
C *** DATA ECHO ***
C
      WRITE(*,2000)XF,ZF
      WRITE(*,2010)W,D
      WRITE(*,2020)DA1,DA
      WRITE(*,2030)RT,VRR
 2000 FORMAT(/' Fault Location (XF,ZF)         =',2F12.3)
 2010 FORMAT( ' Width and Dislocation          =',F12.3,F12.5)
 2020 FORMAT( ' Dip Angle (deg) and (rad)      =',2F12.5)
 2030 FORMAT( ' Rise Time and Rupture Velocity =',F12.3,F12.5)
C
      RETURN
      END
